@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream.c,v 1.15 2004/11/21 21:53:31 hoa Exp $
+ * $Id: mailstream.c,v 1.16 2005/06/01 12:21:57 smarinier Exp $
  */
 
 #include "mailstream.h"
@@ -394,6 +394,10 @@ ssize_t mailstream_feed_read_buffer(mailstream * s)
   return s->read_buffer_len;
 }
 
+#ifdef _MSC_VER
+struct timeval mailstream_network_delay =
+{  DEFAULT_NETWORK_TIMEOUT, 0 };
+#else
 struct timeval mailstream_network_delay =
   { .tv_sec = DEFAULT_NETWORK_TIMEOUT, .tv_usec = 0 };
-
+#endif
