@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: data_message_driver.c,v 1.6 2004/11/21 21:53:31 hoa Exp $
+ * $Id: data_message_driver.c,v 1.7 2005/06/01 12:21:57 smarinier Exp $
  */
 
 #include "data_message_driver.h"
@@ -38,8 +38,12 @@
 #include "mailmessage.h"
 #include "mailmessage_tools.h"
 
-#include <unistd.h>
-#include <sys/mman.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
+#if HAVE_SYS_MMAN_H
+#	include <sys/mman.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -58,6 +62,30 @@ static int fetch_size(mailmessage * msg, size_t * result)
 
 
 static mailmessage_driver local_data_message_driver = {
+#ifdef _MSC_VER
+  /* msg_name */ "data",
+  
+  /* msg_initialize */ mailmessage_generic_initialize,
+  /* msg_uninitialize */ mailmessage_generic_uninitialize,
+  
+  /* msg_flush */ mailmessage_generic_flush,
+  /* msg_check */ NULL,
+
+  /* msg_fetch_result_free */ mailmessage_generic_fetch_result_free,
+  
+  /* msg_fetch */ mailmessage_generic_fetch,
+  /* msg_fetch_header */ mailmessage_generic_fetch_header,
+  /* msg_fetch_body */ mailmessage_generic_fetch_body,
+  /* msg_fetch_size */ fetch_size,
+  /* msg_get_bodystructure */ mailmessage_generic_get_bodystructure,
+  /* msg_fetch_section */ mailmessage_generic_fetch_section,
+  /* msg_fetch_section_header */ mailmessage_generic_fetch_section_header,
+  /* msg_fetch_section_mime */ mailmessage_generic_fetch_section_mime,
+  /* msg_fetch_section_body */ mailmessage_generic_fetch_section_body,
+  /* msg_fetch_envelope */ mailmessage_generic_fetch_envelope,
+
+  /* msg_get_flags */ NULL,
+#else
   .msg_name = "data",
   
   .msg_initialize = mailmessage_generic_initialize,
@@ -80,6 +108,7 @@ static mailmessage_driver local_data_message_driver = {
   .msg_fetch_envelope = mailmessage_generic_fetch_envelope,
 
   .msg_get_flags = NULL,
+#endif
 };
 
 mailmessage_driver * data_message_driver = &local_data_message_driver;
