@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: dbdriver.c,v 1.4 2005/01/28 01:43:11 hoa Exp $
+ * $Id: dbdriver.c,v 1.6 2005/06/01 16:04:41 hoa Exp $
  */
 
 #include "dbdriver.h"
@@ -87,6 +87,51 @@ static int get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_db_session_driver = {
+#ifdef _MSC_VER
+  /* sess_name */ "db",
+
+  /* sess_initialize */ initialize,
+  /* sess_uninitialize */ uninitialize,
+
+  /* sess_parameters */ NULL,
+
+  /* sess_connect_stream */ NULL,
+  /* sess_connect_path */ connect_path,
+  /* sess_starttls */ NULL,
+  /* sess_login */ NULL,
+  /* sess_logout */ logout,
+  /* sess_noop */ NULL,
+
+  /* sess_build_folder_name */ NULL,
+  /* sess_create_folder */ NULL,
+  /* sess_delete_folder */ NULL,
+  /* sess_rename_folder */ NULL,
+  /* sess_check_folder */ check_folder,
+  /* sess_examine_folder */ NULL,
+  /* sess_select_folder */ NULL,
+  /* sess_expunge_folder */ expunge_folder,
+  /* sess_status_folder */ status_folder,
+  /* sess_messages_number */ messages_number,
+  /* sess_recent_number */ recent_number,
+  /* sess_unseen_number */ unseen_number,
+  /* sess_list_folders */ NULL,
+  /* sess_lsub_folders */ NULL,
+  /* sess_subscribe_folder */ NULL,
+  /* sess_unsubscribe_folder */ NULL,
+
+  /* sess_append_message */ append_message,
+  /* sess_append_message_flags */ append_message_flags,
+  /* sess_copy_message */ NULL,
+  /* sess_move_message */ NULL,
+
+  /* sess_get_message */ get_message,
+  /* sess_get_message_by_uid */ get_message_by_uid,
+
+  /* sess_get_messages_list */ get_messages_list,
+  /* sess_get_envelopes_list */ get_envelopes_list,
+  /* sess_remove_message */ NULL,
+
+#else
   .sess_name = "db",
 
   .sess_initialize = initialize,
@@ -129,6 +174,7 @@ static mailsession_driver local_db_session_driver = {
 
   .sess_get_message = get_message,
   .sess_get_message_by_uid = get_message_by_uid,
+#endif
 };
 
 mailsession_driver * db_session_driver = &local_db_session_driver;
@@ -776,6 +822,7 @@ static int append_message_flags(mailsession * session,
     goto err;
   }
   
+  num = 0;
   r = db_get_next_msg_number(maildb, &num);
   if (r != MAIL_NO_ERROR) {
     res = r;
