@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver.c,v 1.47 2004/11/21 21:53:31 hoa Exp $
+ * $Id: imapdriver.c,v 1.48 2005/06/01 12:21:58 smarinier Exp $
  */
 
 #include "imapdriver.h"
@@ -127,6 +127,54 @@ static int imapdriver_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_imap_session_driver = {
+#ifdef _MSC_VER
+  /* sess_name */ "imap",
+
+  /* sess_initialize */ imapdriver_initialize,
+  /* sess_uninitialize */ imapdriver_uninitialize,
+
+  /* sess_parameters */ NULL,
+
+  /* sess_connect_stream */ imapdriver_connect_stream,
+  /* sess_connect_path */ NULL,
+  /* sess_starttls */ imapdriver_starttls,
+  /* sess_login */ imapdriver_login,
+  /* sess_logout */ imapdriver_logout,
+  /* sess_noop */ imapdriver_noop,
+
+  /* sess_build_folder_name */ imapdriver_build_folder_name,
+  /* sess_create_folder */ imapdriver_create_folder,
+  /* sess_delete_folder */ imapdriver_delete_folder,
+  /* sess_rename_folder */ imapdriver_rename_folder,
+  /* sess_check_folder */ imapdriver_check_folder,
+  /* sess_examine_folder */ imapdriver_examine_folder,
+  /* sess_select_folder */ imapdriver_select_folder,
+  /* sess_expunge_folder */ imapdriver_expunge_folder,
+  /* sess_status_folder */ imapdriver_status_folder,
+  /* sess_messages_number */ imapdriver_messages_number,
+  /* sess_recent_number */ imapdriver_recent_number,
+  /* sess_unseen_number */ imapdriver_unseen_number,
+  /* sess_list_folders */ imapdriver_list_folders,
+  /* sess_lsub_folders */ imapdriver_lsub_folders,
+  /* sess_subscribe_folder */ imapdriver_subscribe_folder,
+  /* sess_unsubscribe_folder */ imapdriver_unsubscribe_folder,
+
+  /* sess_append_message */ imapdriver_append_message,
+  /* sess_append_message_flags */ imapdriver_append_message_flags,
+  /* sess_copy_message */ imapdriver_copy_message,
+  /* sess_move_message */ NULL,
+
+  /* sess_get_message */ imapdriver_get_message,
+  /* sess_get_message_by_uid */ imapdriver_get_message_by_uid,
+
+  /* sess_get_messages_list */ imapdriver_get_messages_list,
+  /* sess_get_envelopes_list */ imapdriver_get_envelopes_list,
+  /* sess_remove_message */ NULL,
+#if 0
+  /* sess_search_messages */ imapdriver_search_messages,
+#endif
+  
+#else
   .sess_name = "imap",
 
   .sess_initialize = imapdriver_initialize,
@@ -172,6 +220,7 @@ static mailsession_driver local_imap_session_driver = {
   
   .sess_get_message = imapdriver_get_message,
   .sess_get_message_by_uid = imapdriver_get_message_by_uid,
+#endif
 };
 
 mailsession_driver * imap_session_driver = &local_imap_session_driver;
