@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_cached.c,v 1.44 2005/01/29 15:40:23 hoa Exp $
+ * $Id: imapdriver_cached.c,v 1.47 2005/06/01 16:04:41 hoa Exp $
  */
 
 #include "imapdriver_cached.h"
@@ -42,7 +42,9 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
-#include <unistd.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
 #include <stdlib.h>
 
 #include "mail.h"
@@ -135,6 +137,54 @@ static int imapdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_imap_cached_session_driver = {
+#ifdef _MSC_VER
+  /* sess_name */ "imap-cached",
+
+  /* sess_initialize */ imapdriver_cached_initialize,
+  /* sess_uninitialize */ imapdriver_cached_uninitialize,
+
+  /* sess_parameters */ imapdriver_cached_parameters,
+
+  /* sess_connect_stream */ imapdriver_cached_connect_stream,
+  /* sess_connect_path */ NULL,
+  /* sess_starttls */ imapdriver_cached_starttls,
+  /* sess_login */ imapdriver_cached_login,
+  /* sess_logout */ imapdriver_cached_logout,
+  /* sess_noop */ imapdriver_cached_noop,
+
+  /* sess_build_folder_name */ imapdriver_cached_build_folder_name,
+  /* sess_create_folder */ imapdriver_cached_create_folder,
+  /* sess_delete_folder */ imapdriver_cached_delete_folder,
+  /* sess_rename_folder */ imapdriver_cached_rename_folder,
+  /* sess_check_folder */ imapdriver_cached_check_folder,
+  /* sess_examine_folder */ imapdriver_cached_examine_folder,
+  /* sess_select_folder */ imapdriver_cached_select_folder,
+  /* sess_expunge_folder */ imapdriver_cached_expunge_folder,
+  /* sess_status_folder */ imapdriver_cached_status_folder,
+  /* sess_messages_number */ imapdriver_cached_messages_number,
+  /* sess_recent_number */ imapdriver_cached_recent_number,
+  /* sess_unseen_number */ imapdriver_cached_unseen_number,
+  /* sess_list_folders */ imapdriver_cached_list_folders,
+  /* sess_lsub_folders */ imapdriver_cached_lsub_folders,
+  /* sess_subscribe_folder */ imapdriver_cached_subscribe_folder,
+  /* sess_unsubscribe_folder */ imapdriver_cached_unsubscribe_folder,
+
+  /* sess_append_message */ imapdriver_cached_append_message,
+  /* sess_append_message_flags */ imapdriver_cached_append_message_flags,
+  /* sess_copy_message */ imapdriver_cached_copy_message,
+  /* sess_move_message */ NULL,
+
+  /* sess_get_message */ imapdriver_cached_get_message,
+  /* sess_get_message_by_uid */ imapdriver_cached_get_message_by_uid,
+
+  /* sess_get_messages_list */ imapdriver_cached_get_messages_list,
+  /* sess_get_envelopes_list */ imapdriver_cached_get_envelopes_list,
+  /* sess_remove_message */ imapdriver_cached_remove_message,
+#if 0
+  /* sess_search_messages */ imapdriver_cached_search_messages,
+#endif
+
+#else
   .sess_name = "imap-cached",
 
   .sess_initialize = imapdriver_cached_initialize,
@@ -180,6 +230,7 @@ static mailsession_driver local_imap_cached_session_driver = {
 
   .sess_get_message = imapdriver_cached_get_message,
   .sess_get_message_by_uid = imapdriver_cached_get_message_by_uid,
+#endif
 };
 
 mailsession_driver * imap_cached_session_driver =
@@ -642,6 +693,7 @@ static int imapdriver_cached_select_folder(mailsession * session, char * mb)
 
   check_for_uid_cache(session);
 
+  quoted_mb = NULL;
   r = get_cache_folder(session, &quoted_mb);
   if (r != MAIL_NO_ERROR)
     return r;
@@ -1080,10 +1132,12 @@ static int get_flags_list(mailsession * session,
       return imap_error_to_mail_error(r);
     }
     
+#if 0
     if (clist_begin(fetch_result) == NULL) {
       res = MAIL_ERROR_FETCH;
       goto err;
     }
+#endif
     
     r = imap_fetch_result_to_envelop_list(fetch_result, env_list);
     mailimap_fetch_list_free(fetch_result);
