@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_message.c,v 1.20 2004/11/21 21:53:32 hoa Exp $
+ * $Id: imapdriver_message.c,v 1.21 2005/06/01 12:21:58 smarinier Exp $
  */
 
 #include "imapdriver_message.h"
@@ -97,6 +97,30 @@ static void imap_flush(mailmessage * msg_info);
 static void imap_check(mailmessage * msg_info);
 
 static mailmessage_driver local_imap_message_driver = {
+#ifdef _MSC_VER
+  /* msg_name */ "imap",
+  
+  /* msg_initialize */ imap_initialize,
+  /* msg_uninitialize */ NULL,
+
+  /* msg_flush */ imap_flush,
+  /* msg_check */ imap_check,
+  
+  /* msg_fetch_result_free */ imap_fetch_result_free,
+
+  /* msg_fetch */ imap_fetch,
+  /* msg_fetch_header */ imap_fetch_header,
+  /* msg_fetch_body */ imap_fetch_body,
+  /* msg_fetch_size */ imap_fetch_size,
+  /* msg_get_bodystructure */ imap_get_bodystructure,
+  /* msg_fetch_section */ imap_fetch_section,
+  /* msg_fetch_section_header */ imap_fetch_section_header,
+  /* msg_fetch_section_mime */ imap_fetch_section_mime,
+  /* msg_fetch_section_body */ imap_fetch_section_body,
+  /* msg_fetch_envelope */ imap_fetch_envelope,
+
+  /* msg_get_flags */ imap_get_flags,
+#else
   .msg_name = "imap",
   
   .msg_initialize = imap_initialize,
@@ -119,6 +143,7 @@ static mailmessage_driver local_imap_message_driver = {
   .msg_fetch_envelope = imap_fetch_envelope,
 
   .msg_get_flags = imap_get_flags,
+#endif
 };
 
 mailmessage_driver * imap_message_driver = &local_imap_message_driver;
