@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_tools.c,v 1.20 2004/11/21 21:53:32 hoa Exp $
+ * $Id: imapdriver_tools.c,v 1.21 2005/06/01 16:04:41 hoa Exp $
  */
 
 #include "imapdriver_tools.h"
@@ -708,7 +708,11 @@ imap_language_to_mime_language(struct mailimap_body_fld_lang * imap_lang,
   case MAILIMAP_BODY_FLD_LANG_LIST:
     for(cur = clist_begin(imap_lang->lg_data.lg_list) ;
         cur != NULL ; cur = clist_next(cur)) {
-      single = strdup(clist_content(cur));
+      char * original_single;
+      
+      original_single = clist_content(cur);
+      
+      single = strdup(original_single);
       if (single == NULL) {
 	res = MAIL_ERROR_MEMORY;
 	goto free;
@@ -961,6 +965,7 @@ imap_body_type_basic_to_body(struct mailimap_body_type_basic *
   int res;
   uint32_t mime_size;
 
+  content = NULL;
   r = imap_body_media_basic_to_content_type(imap_type_basic->bd_media_basic,
       imap_type_basic->bd_fields->bd_parameter, &content);
   if (r != MAIL_NO_ERROR) {
@@ -1289,6 +1294,7 @@ imap_body_type_1part_to_body(struct mailimap_body_type_1part *
   int r;
   int res;
   
+  body = NULL;
   switch (type_1part->bd_type) {
   case MAILIMAP_BODY_TYPE_1PART_BASIC:
     r = imap_body_type_basic_to_body(type_1part->bd_data.bd_type_basic,
@@ -1439,6 +1445,7 @@ int imap_body_to_body(struct mailimap_body * imap_body,
   int r;
   int res;
 
+  body = NULL;
   switch (imap_body->bd_type) {
   case MAILIMAP_BODY_1PART:
     r = imap_body_type_1part_to_body(imap_body->bd_data.bd_body_1part, &body);
@@ -1730,6 +1737,7 @@ imap_mailbox_list_to_address_list(clist * imap_mailbox_list,
         (imap_addr->ad_mailbox_name != NULL)) {
       struct mailimf_group * group;
 
+      group = NULL;
       r = imap_mailbox_list_to_group(imap_mailbox_list, &cur, &group);
       if (r != MAIL_NO_ERROR) {
 	res = r;
@@ -3401,6 +3409,7 @@ int imap_fetch_flags(mailimap * imap,
     return imap_error_to_mail_error(r);
   }
   
+  flags = NULL;
   r = imap_fetch_result_to_flags(fetch_result, index, &flags);
   mailimap_fetch_list_free(fetch_result);
 
@@ -3523,6 +3532,7 @@ int imap_get_messages_list(mailimap * imap,
     goto err;
   }
 
+  env_list = NULL;
   r = uid_list_to_env_list(fetch_result, &env_list, session, driver);
   mailimap_fetch_list_free(fetch_result);
 
