@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapstorage.c,v 1.11 2004/11/21 21:53:32 hoa Exp $
+ * $Id: imapstorage.c,v 1.12 2005/06/01 12:21:58 smarinier Exp $
  */
 
 #include "imapstorage.h"
@@ -56,12 +56,20 @@ imap_mailstorage_get_folder_session(struct mailstorage * storage,
 static void imap_mailstorage_uninitialize(struct mailstorage * storage);
 
 static mailstorage_driver imap_mailstorage_driver = {
+#ifdef _MSC_VER
+  /* sto_name               */ "imap",
+  /* sto_connect            */ imap_mailstorage_connect,
+  /* sto_get_folder_session */ imap_mailstorage_get_folder_session,
+  /* sto_uninitialize       */ imap_mailstorage_uninitialize,
+#else
   .sto_name               = "imap",
   .sto_connect            = imap_mailstorage_connect,
   .sto_get_folder_session = imap_mailstorage_get_folder_session,
   .sto_uninitialize       = imap_mailstorage_uninitialize,
+#endif
 };
 
+LIBETPAN_EXPORT
 int imap_mailstorage_init(struct mailstorage * storage,
     char * imap_servername, uint16_t imap_port,
     char * imap_command,
