@@ -30,19 +30,21 @@
  */
 
 /*
- * $Id: maildirdriver_cached.c,v 1.10 2004/11/21 21:53:32 hoa Exp $
+ * $Id: maildirdriver_cached.c,v 1.12 2005/06/01 16:04:41 hoa Exp $
  */
 
 #include "maildirdriver.h"
 
 #include <stdio.h>
 #include <sys/types.h>
-#include <dirent.h>
-#include <unistd.h>
+#ifndef _MSC_VER
+#	include <dirent.h>
+#	include <unistd.h>
+#	include <sys/mman.h>
+#endif
 #include <sys/stat.h>
 #include <ctype.h>
 #include <fcntl.h>
-#include <sys/mman.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -104,6 +106,54 @@ static int get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_maildir_cached_session_driver = {
+#ifdef _MSC_VER
+   /* sess_name */ "maildir-cached",
+
+  /* sess_initialize */ initialize,
+  /* sess_uninitialize */ uninitialize,
+
+  /* sess_parameters */ parameters,
+
+  /* sess_connect_stream */ NULL,
+  /* sess_connect_path */ connect_path,
+  /* sess_starttls */ NULL,
+  /* sess_login */ NULL,
+  /* sess_logout */ logout,
+  /* sess_noop */ NULL,
+
+  /* sess_build_folder_name */ NULL,
+  /* sess_create_folder */ NULL,
+  /* sess_delete_folder */ NULL,
+  /* sess_rename_folder */ NULL,
+  /* sess_check_folder */ check_folder,
+  /* sess_examine_folder */ NULL,
+  /* sess_select_folder */ NULL,
+  /* sess_expunge_folder */ expunge_folder,
+  /* sess_status_folder */ status_folder,
+  /* sess_messages_number */ messages_number,
+  /* sess_recent_number */ recent_number,
+  /* sess_unseen_number */ unseen_number,
+  /* sess_list_folders */ NULL,
+  /* sess_lsub_folders */ NULL,
+  /* sess_subscribe_folder */ NULL,
+  /* sess_unsubscribe_folder */ NULL,
+
+  /* sess_append_message */ append_message,
+  /* sess_append_message_flags */ append_message_flags,
+  /* sess_copy_message */ NULL,
+  /* sess_move_message */ NULL,
+
+  /* sess_get_message */ get_message,
+  /* sess_get_message_by_uid */ get_message_by_uid,
+
+  /* sess_get_messages_list */ get_messages_list,
+  /* sess_get_envelopes_list */ get_envelopes_list,
+  /* sess_remove_message */ NULL,
+#if 0
+  /* sess_search_messages */ maildriver_generic_search_messages,
+#endif
+
+#else
   .sess_name = "maildir-cached",
 
   .sess_initialize = initialize,
@@ -149,6 +199,7 @@ static mailsession_driver local_maildir_cached_session_driver = {
 
   .sess_get_message = get_message,
   .sess_get_message_by_uid = get_message_by_uid,
+#endif
 };
 
 mailsession_driver * maildir_cached_session_driver =
@@ -393,6 +444,7 @@ static int connect_path(mailsession * session, char * path)
     goto err;
   }
   
+  quoted_mb = NULL;
   r = get_cache_folder(session, &quoted_mb);
   if (r != MAIL_NO_ERROR) {
     res = r;
