@@ -30,10 +30,16 @@
  */
 
 /*
- * $Id: maildirdriver_message.c,v 1.4 2004/11/21 21:53:32 hoa Exp $
+ * $Id: maildirdriver_message.c,v 1.6 2005/06/01 20:23:15 hoa Exp $
  */
 
 #include "maildirdriver_message.h"
+
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
 #include "maildirdriver_tools.h"
 
 #include "mailmessage_tools.h"
@@ -41,13 +47,20 @@
 #include "maildir.h"
 #include "generic_cache.h"
 
-#include <unistd.h>
-#include <sys/mman.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
+#if HAVE_SYS_MMAN_H
+#	include <sys/mman.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
 #include <stdlib.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#endif
 
 static int get_flags(mailmessage * msg_info,
     struct mail_flags ** result);
@@ -61,6 +74,30 @@ static int initialize(mailmessage * msg_info);
 static void check(mailmessage * msg_info);
 
 static mailmessage_driver local_maildir_message_driver = {
+#ifdef _MSC_VER
+  /* msg_name */ "maildir",
+
+  /* msg_initialize */ initialize,
+  /* msg_uninitialize */ mailmessage_generic_uninitialize,
+
+  /* msg_flush */ mailmessage_generic_flush,
+  /* msg_check */ check,
+
+  /* msg_fetch_result_free */ mailmessage_generic_fetch_result_free,
+
+  /* msg_fetch */ mailmessage_generic_fetch,
+  /* msg_fetch_header */ mailmessage_generic_fetch_header,
+  /* msg_fetch_body */ mailmessage_generic_fetch_header,
+  /* msg_fetch_size */ NULL,
+  /* msg_get_bodystructure */ mailmessage_generic_get_bodystructure,
+  /* msg_fetch_section */ mailmessage_generic_fetch_section,
+  /* msg_fetch_section_header */ mailmessage_generic_fetch_section_header,
+  /* msg_fetch_section_mime */ mailmessage_generic_fetch_section_mime,
+  /* msg_fetch_section_body */ mailmessage_generic_fetch_section_body,
+  /* msg_fetch_envelope */ mailmessage_generic_fetch_envelope,
+
+  /* msg_get_flags */ get_flags
+#else
   .msg_name = "maildir",
 
   .msg_initialize = initialize,
@@ -83,6 +120,7 @@ static mailmessage_driver local_maildir_message_driver = {
   .msg_fetch_envelope = mailmessage_generic_fetch_envelope,
 
   .msg_get_flags = get_flags,
+#endif
 };
 
 mailmessage_driver * maildir_message_driver = &local_maildir_message_driver;
