@@ -30,15 +30,19 @@
  */
 
 /*
- * $Id: mboxdriver_cached.c,v 1.45 2004/11/21 21:53:32 hoa Exp $
+ * $Id: mboxdriver_cached.c,v 1.48 2005/06/19 21:02:07 hoa Exp $
  */
 
 #include "mboxdriver_cached.h"
 
 #include <stdio.h>
 #include <string.h>
-#include <dirent.h>
-#include <unistd.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#else
+#	include <dirent.h>
+#	include <unistd.h>
+#endif
 #include <ctype.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -108,6 +112,55 @@ static int mboxdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mbox_cached_session_driver = {
+#ifdef _MSC_VER
+  /* sess_name */ "mbox-cached",
+
+  /* sess_initialize */ mboxdriver_cached_initialize,
+  /* sess_uninitialize */ mboxdriver_cached_uninitialize,
+
+  /* sess_parameters */ mboxdriver_cached_parameters,
+
+  /* sess_connect_stream */ NULL,
+  /* sess_connect_path */ mboxdriver_cached_connect_path,
+  /* sess_starttls */ NULL,
+  /* sess_login */ NULL,
+  /* sess_logout */ mboxdriver_cached_logout,
+  /* sess_noop */ NULL,
+
+  /* sess_build_folder_name */ NULL,
+  /* sess_create_folder */ NULL,
+  /* sess_delete_folder */ NULL,
+  /* sess_rename_folder */ NULL,
+  /* sess_check_folder */ mboxdriver_cached_check_folder,
+  /* sess_examine_folder */ NULL,
+  /* sess_select_folder */ NULL,
+  /* sess_expunge_folder */ mboxdriver_cached_expunge_folder,
+  /* sess_status_folder */ mboxdriver_cached_status_folder,
+  /* sess_messages_number */ mboxdriver_cached_messages_number,
+  /* sess_recent_number */ mboxdriver_cached_recent_number,
+  /* sess_unseen_number */ mboxdriver_cached_unseen_number,
+  /* sess_list_folders */ NULL,
+  /* sess_lsub_folders */ NULL,
+  /* sess_subscribe_folder */ NULL,
+  /* sess_unsubscribe_folder */ NULL,
+
+  /* sess_append_message */ mboxdriver_cached_append_message,
+  /* sess_append_message_flags */ mboxdriver_cached_append_message_flags,
+  
+  /* sess_copy_message */ NULL,
+  /* sess_move_message */ NULL,
+
+  /* sess_get_message */ mboxdriver_cached_get_message,
+  /* sess_get_message_by_uid */ mboxdriver_cached_get_message_by_uid,
+
+  /* sess_get_messages_list */ mboxdriver_cached_get_messages_list,
+  /* sess_get_envelopes_list */ mboxdriver_cached_get_envelopes_list,
+  /* sess_remove_message */ mboxdriver_cached_remove_message,
+#if 0
+  /* sess_search_messages */ maildriver_generic_search_messages,
+#endif
+
+#else
   .sess_name = "mbox-cached",
 
   .sess_initialize = mboxdriver_cached_initialize,
@@ -154,6 +207,7 @@ static mailsession_driver local_mbox_cached_session_driver = {
 
   .sess_get_message = mboxdriver_cached_get_message,
   .sess_get_message_by_uid = mboxdriver_cached_get_message_by_uid,
+#endif
 };
 
 mailsession_driver * mbox_cached_session_driver =
@@ -567,7 +621,6 @@ static int read_max_uid_value(mailsession * session, uint32_t * result)
   
   r = mailimf_cache_int_read(mmapstr, &cur_token, &written_uid);
   if (r != MAIL_NO_ERROR) {
-    fclose(f);
     res = r;
     goto free_mmapstr;
   }
@@ -603,6 +656,7 @@ static int mboxdriver_cached_connect_path(mailsession * session, char * path)
     goto err;
   }
   
+  quoted_mb = NULL;
   r = get_cache_directory(session, path, &quoted_mb);
   if (r != MAIL_NO_ERROR) {
     res = r;
