@@ -30,19 +30,21 @@
  */
 
 /*
- * $Id: mhdriver.c,v 1.28 2004/11/21 21:53:33 hoa Exp $
+ * $Id: mhdriver.c,v 1.29 2005/06/01 12:21:59 smarinier Exp $
  */
 
 #include "mhdriver.h"
 
 #include <stdio.h>
 #include <sys/types.h>
-#include <dirent.h>
-#include <unistd.h>
+#ifndef _MSC_VER
+#	include <dirent.h>
+#	include <unistd.h>
+#	include <sys/mman.h>
+#endif
 #include <sys/stat.h>
 #include <ctype.h>
 #include <fcntl.h>
-#include <sys/mman.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -110,6 +112,54 @@ static int mhdriver_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mh_session_driver = {
+#ifdef _MSC_VER
+  /* sess_name */ "mh",
+
+  /* sess_initialize */ mhdriver_initialize,
+  /* sess_uninitialize */ mhdriver_uninitialize,
+
+  /* sess_parameters */ NULL,
+
+  /* sess_connect_stream */ NULL,
+  /* sess_connect_path */ mhdriver_connect_path,
+  /* sess_starttls */ NULL,
+  /* sess_login */ NULL,
+  /* sess_logout */ mhdriver_logout,
+  /* sess_noop */ NULL,
+
+  /* sess_build_folder_name */ mhdriver_build_folder_name,
+  /* sess_create_folder */ mhdriver_create_folder,
+  /* sess_delete_folder */ mhdriver_delete_folder,
+  /* sess_rename_folder */ mhdriver_rename_folder,
+  /* sess_check_folder */ NULL,
+  /* sess_examine_folder */ NULL,
+  /* sess_select_folder */ mhdriver_select_folder,
+  /* sess_expunge_folder */ NULL,
+  /* sess_status_folder */ mhdriver_status_folder,
+  /* sess_messages_number */ mhdriver_messages_number,
+  /* sess_recent_number */ mhdriver_messages_number,
+  /* sess_unseen_number */ mhdriver_messages_number,
+  /* sess_list_folders */ mhdriver_list_folders,
+  /* sess_lsub_folders */ mhdriver_lsub_folders,
+  /* sess_subscribe_folder */ mhdriver_subscribe_folder,
+  /* sess_unsubscribe_folder */ mhdriver_unsubscribe_folder,
+
+  /* sess_append_message */ mhdriver_append_message, 
+  /* sess_append_message_flags */ mhdriver_append_message_flags,
+  /* sess_copy_message */ mhdriver_copy_message,
+  /* sess_move_message */ mhdriver_move_message,
+
+  /* sess_get_message */ mhdriver_get_message,
+  /* sess_get_message_by_uid */ mhdriver_get_message_by_uid,
+
+  /* sess_get_messages_list */ mhdriver_get_messages_list,
+  /* sess_get_envelopes_list */ maildriver_generic_get_envelopes_list,
+  /* sess_remove_message */ mhdriver_remove_message,
+#if 0
+  /* sess_search_messages */ maildriver_generic_search_messages,
+#endif
+
+#else
   .sess_name = "mh",
 
   .sess_initialize = mhdriver_initialize,
@@ -155,6 +205,7 @@ static mailsession_driver local_mh_session_driver = {
 
   .sess_get_message = mhdriver_get_message,
   .sess_get_message_by_uid = mhdriver_get_message_by_uid,
+#endif
 };
 
 mailsession_driver * mh_session_driver = &local_mh_session_driver;
