@@ -30,19 +30,23 @@
  */
 
 /*
- * $Id: mhdriver_cached.c,v 1.39 2004/11/21 21:53:33 hoa Exp $
+ * $Id: mhdriver_cached.c,v 1.41 2005/06/01 16:04:43 hoa Exp $
  */
 
 #include "mhdriver_cached.h"
 
 #include <stdio.h>
 #include <sys/types.h>
-#include <dirent.h>
-#include <unistd.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#else
+#	include <dirent.h>
+#	include <unistd.h>
+#	include <sys/mman.h>
+#endif
 #include <sys/stat.h>
 #include <ctype.h>
 #include <fcntl.h>
-#include <sys/mman.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -135,6 +139,54 @@ static int mhdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mh_cached_session_driver = {
+#ifdef _MSC_VER
+  /* sess_name */ "mh-cached",
+
+  /* sess_initialize */ mhdriver_cached_initialize,
+  /* sess_uninitialize */ mhdriver_cached_uninitialize,
+
+  /* sess_parameters */ mhdriver_cached_parameters,
+
+  /* sess_connect_stream */ NULL,
+  /* sess_connect_path */ mhdriver_cached_connect_path,
+  /* sess_starttls */ NULL,
+  /* sess_login */ NULL,
+  /* sess_logout */ mhdriver_cached_logout,
+  /* sess_noop */ NULL,
+
+  /* sess_build_folder_name */ mhdriver_cached_build_folder_name,
+  /* sess_create_folder */ mhdriver_cached_create_folder,
+  /* sess_delete_folder */ mhdriver_cached_delete_folder,
+  /* sess_rename_folder */ mhdriver_cached_rename_folder,
+  /* sess_check_folder */ mhdriver_cached_check_folder,
+  /* sess_examine_folder */ NULL,
+  /* sess_select_folder */ mhdriver_cached_select_folder,
+  /* sess_expunge_folder */ mhdriver_cached_expunge_folder,
+  /* sess_status_folder */ mhdriver_cached_status_folder,
+  /* sess_messages_number */ mhdriver_cached_messages_number,
+  /* sess_recent_number */ mhdriver_cached_recent_number,
+  /* sess_unseen_number */ mhdriver_cached_unseen_number,
+  /* sess_list_folders */ mhdriver_cached_list_folders,
+  /* sess_lsub_folders */ mhdriver_cached_lsub_folders,
+  /* sess_subscribe_folder */ mhdriver_cached_subscribe_folder,
+  /* sess_unsubscribe_folder */ mhdriver_cached_unsubscribe_folder,
+
+  /* sess_append_message */ mhdriver_cached_append_message,
+  /* sess_append_message_flags */ mhdriver_cached_append_message_flags,
+  /* sess_copy_message */ mhdriver_cached_copy_message,
+  /* sess_move_message */ mhdriver_cached_move_message,
+
+  /* sess_get_message */ mhdriver_cached_get_message,
+  /* sess_get_message_by_uid */ mhdriver_cached_get_message_by_uid,
+
+  /* sess_get_messages_list */ mhdriver_cached_get_messages_list,
+  /* sess_get_envelopes_list */ mhdriver_cached_get_envelopes_list,
+  /* sess_remove_message */ mhdriver_cached_remove_message,
+#if 0
+  /* sess_search_messages */ maildriver_generic_search_messages,
+#endif
+
+#else
   .sess_name = "mh-cached",
 
   .sess_initialize = mhdriver_cached_initialize,
@@ -180,6 +232,7 @@ static mailsession_driver local_mh_cached_session_driver = {
 
   .sess_get_message = mhdriver_cached_get_message,
   .sess_get_message_by_uid = mhdriver_cached_get_message_by_uid,
+#endif
 };
 
 mailsession_driver * mh_cached_session_driver =
@@ -614,6 +667,7 @@ static int mhdriver_cached_select_folder(mailsession * session, char * mb)
       cached_data->mh_quoted_mb,
       cached_data->mh_flags_store);
   
+  quoted_mb = NULL;
   r = get_cache_directory(session, mb, &quoted_mb);
   if (r != MAIL_NO_ERROR) {
     res = r;
