@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mime_message_driver.c,v 1.8 2004/12/13 23:18:28 hoa Exp $
+ * $Id: mime_message_driver.c,v 1.9 2005/06/01 12:21:59 smarinier Exp $
  */
 
 #include "mime_message_driver.h"
@@ -39,8 +39,12 @@
 
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <unistd.h>
-#include <sys/mman.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
+#if HAVE_SYS_MMAN_H
+#	include <sys/mman.h>
+#endif
 #include <stdlib.h>
 #include <string.h>
 
@@ -469,7 +473,6 @@ static int file_body_body_to_mmapstr(FILE * f,
 static int body_body_to_mmapstr(char * data, size_t size,
     char ** result, size_t * result_len)
 {
-  MMAPString * mmapstr;
   size_t cur_token;
   int res;
   int r;
@@ -887,6 +890,30 @@ static int fetch_size(mailmessage * msg_info,
 
 
 static mailmessage_driver local_mime_message_driver = {
+#ifdef _MSC_VER
+  /* msg_name */ "mime",
+  
+  /* msg_initialize */ initialize,
+  /* msg_uninitialize */ uninitialize,
+  
+  /* msg_flush */ flush,
+  /* msg_check */ check,
+
+  /* msg_fetch_result_free */ fetch_result_free,
+  
+  /* msg_fetch */ fetch,
+  /* msg_fetch_header */ fetch_header,
+  /* msg_fetch_body */ fetch_body,
+  /* msg_fetch_size */ fetch_size,
+  /* msg_get_bodystructure */ get_bodystructure,
+  /* msg_fetch_section */ fetch_section,
+  /* msg_fetch_section_header */ fetch_section_header,
+  /* msg_fetch_section_mime */ fetch_section_mime,
+  /* msg_fetch_section_body */ fetch_section_body,
+  /* msg_fetch_envelope */ mailmessage_generic_fetch_envelope,
+
+  /* msg_get_flags */ NULL,
+#else
   .msg_name = "mime",
   
   .msg_initialize = initialize,
@@ -909,6 +936,7 @@ static mailmessage_driver local_mime_message_driver = {
   .msg_fetch_envelope = mailmessage_generic_fetch_envelope,
 
   .msg_get_flags = NULL,
+#endif
 };
 
 mailmessage_driver * mime_message_driver = &local_mime_message_driver;
