@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpdriver.c,v 1.44 2004/11/21 21:53:33 hoa Exp $
+ * $Id: nntpdriver.c,v 1.46 2005/06/01 16:04:43 hoa Exp $
  */
 
 #include "nntpdriver.h"
@@ -100,6 +100,54 @@ static int nntpdriver_get_message_by_uid(mailsession * session,
 static int nntpdriver_noop(mailsession * session);
 
 static mailsession_driver local_nntp_session_driver = {
+#ifdef _MSC_VER
+  /* sess_name */ "nntp",
+
+  /* sess_initialize */ nntpdriver_initialize,
+  /* sess_uninitialize */ nntpdriver_uninitialize,
+
+  /* sess_parameters */ nntpdriver_parameters,
+
+  /* sess_connect_stream */ nntpdriver_connect_stream,
+  /* sess_connect_path */ NULL,
+  /* sess_starttls */ NULL,
+  /* sess_login */ nntpdriver_login,
+  /* sess_logout */ nntpdriver_logout,
+  /* sess_noop */ nntpdriver_noop,
+
+  /* sess_build_folder_name */ NULL,
+  /* sess_create_folder */ NULL,
+  /* sess_delete_folder */ NULL,
+  /* sess_rename_folder */ NULL,
+  /* sess_check_folder */ NULL,
+  /* sess_examine_folder */ NULL,
+  /* sess_select_folder */ nntpdriver_select_folder,
+  /* sess_expunge_folder */ NULL,
+  /* sess_status_folder */ nntpdriver_status_folder,
+  /* sess_messages_number */ nntpdriver_messages_number,
+  /* sess_recent_number */ nntpdriver_messages_number,
+  /* sess_unseen_number */ nntpdriver_messages_number,
+  /* sess_list_folders */ nntpdriver_list_folders,
+  /* sess_lsub_folders */ nntpdriver_lsub_folders,
+  /* sess_subscribe_folder */ nntpdriver_subscribe_folder,
+  /* sess_unsubscribe_folder */ nntpdriver_unsubscribe_folder,
+
+  /* sess_append_message */ nntpdriver_append_message,
+  /* sess_append_message_flags */ nntpdriver_append_message_flags,
+  /* sess_copy_message */ NULL,
+  /* sess_move_message */ NULL,
+
+  /* sess_get_message */ nntpdriver_get_message,
+  /* sess_get_message_by_uid */ nntpdriver_get_message_by_uid,
+
+  /* sess_get_messages_list */ nntpdriver_get_messages_list,
+  /* sess_get_envelopes_list */ nntpdriver_get_envelopes_list,
+  /* sess_remove_message */ NULL,
+#if 0
+  /* sess_search_messages */ maildriver_generic_search_messages,
+#endif
+
+#else
   .sess_name = "nntp",
 
   .sess_initialize = nntpdriver_initialize,
@@ -145,6 +193,7 @@ static mailsession_driver local_nntp_session_driver = {
 
   .sess_get_message = nntpdriver_get_message,
   .sess_get_message_by_uid = nntpdriver_get_message_by_uid,
+#endif
 };
 
 
@@ -829,6 +878,7 @@ nntpdriver_get_envelopes_list(mailsession * session,
 	if (item->ovr_article == info->msg_index) {
 
 	  if (info->msg_fields == NULL) {
+            fields = NULL;
 	    r = xover_resp_to_fields(item, &fields);
 	    if (r == MAIL_NO_ERROR) {
 	      info->msg_fields = fields;
