@@ -30,11 +30,16 @@
  */
 
 /*
- * $Id: nntpdriver_cached.c,v 1.46 2005/01/28 01:43:11 hoa Exp $
+ * $Id: nntpdriver_cached.c,v 1.48 2005/06/01 20:23:15 hoa Exp $
  */
 
 #include "nntpdriver_cached.h"
 
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
 #include "libetpan-config.h"
 
 #include <string.h>
@@ -42,8 +47,13 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <unistd.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
 #include <stdlib.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#endif
 
 #include "mail_cache_db.h"
 
@@ -130,6 +140,54 @@ static int nntpdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_nntp_cached_session_driver = {
+#ifdef _MSC_VER
+  /* sess_name */ "nntp-cached",
+
+  /* sess_initialize */ nntpdriver_cached_initialize,
+  /* sess_uninitialize */ nntpdriver_cached_uninitialize,
+
+  /* sess_parameters */ nntpdriver_cached_parameters,
+
+  /* sess_connect_stream */ nntpdriver_cached_connect_stream,
+  /* sess_connect_path */ NULL,
+  /* sess_starttls */ NULL,
+  /* sess_login */ nntpdriver_cached_login,
+  /* sess_logout */ nntpdriver_cached_logout,
+  /* sess_noop */ nntpdriver_cached_noop,
+
+  /* sess_build_folder_name */ NULL,
+  /* sess_create_folder */ NULL,
+  /* sess_delete_folder */ NULL,
+  /* sess_rename_folder */ NULL,
+  /* sess_check_folder */ nntpdriver_cached_check_folder,
+  /* sess_examine_folder */ NULL,
+  /* sess_select_folder */ nntpdriver_cached_select_folder,
+  /* sess_expunge_folder */ NULL,
+  /* sess_status_folder */ nntpdriver_cached_status_folder,
+  /* sess_messages_number */ nntpdriver_cached_messages_number,
+  /* sess_recent_number */ nntpdriver_cached_recent_number,
+  /* sess_unseen_number */ nntpdriver_cached_unseen_number,
+  /* sess_list_folders */ nntpdriver_cached_list_folders,
+  /* sess_lsub_folders */ nntpdriver_cached_lsub_folders,
+  /* sess_subscribe_folder */ nntpdriver_cached_subscribe_folder,
+  /* sess_unsubscribe_folder */ nntpdriver_cached_unsubscribe_folder,
+
+  /* sess_append_message */ nntpdriver_cached_append_message,
+  /* sess_append_message_flags */ nntpdriver_cached_append_message_flags,
+  /* sess_copy_message */ NULL,
+  /* sess_move_message */ NULL,
+
+  /* sess_get_message */ nntpdriver_cached_get_message,
+  /* sess_get_message_by_uid */ nntpdriver_cached_get_message_by_uid,
+
+  /* sess_get_messages_list */ nntpdriver_cached_get_messages_list,
+  /* sess_get_envelopes_list */ nntpdriver_cached_get_envelopes_list,
+  /* sess_remove_message */ NULL,
+#if 0
+  /* sess_search_messages */ maildriver_generic_search_messages,
+#endif
+
+#else
   .sess_name = "nntp-cached",
 
   .sess_initialize = nntpdriver_cached_initialize,
@@ -175,6 +233,7 @@ static mailsession_driver local_nntp_cached_session_driver = {
 
   .sess_get_message = nntpdriver_cached_get_message,
   .sess_get_message_by_uid = nntpdriver_cached_get_message_by_uid,
+#endif
 };
 
 
