@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver_cached.c,v 1.41 2004/11/21 21:53:34 hoa Exp $
+ * $Id: pop3driver_cached.c,v 1.42 2005/06/01 12:21:59 smarinier Exp $
  */
 
 #include "pop3driver_cached.h"
@@ -41,7 +41,9 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <string.h>
+#if HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 #include <stdlib.h>
 
 #include "mail.h"
@@ -114,6 +116,54 @@ static int pop3driver_cached_get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_pop3_cached_session_driver = {
+#ifdef _MSC_VER
+  /* sess_name */ "pop3-cached",
+
+  /* sess_initialize */ pop3driver_cached_initialize,
+  /* sess_uninitialize */ pop3driver_cached_uninitialize,
+
+  /* sess_parameters */ pop3driver_cached_parameters,
+
+  /* sess_connect_stream */ pop3driver_cached_connect_stream,
+  /* sess_connect_path */ NULL,
+  /* sess_starttls */ pop3driver_cached_starttls,
+  /* sess_login */ pop3driver_cached_login,
+  /* sess_logout */ pop3driver_cached_logout,
+  /* sess_noop */ pop3driver_cached_noop,
+
+  /* sess_build_folder_name */ NULL,
+  /* sess_create_folder */ NULL,
+  /* sess_delete_folder */ NULL,
+  /* sess_rename_folder */ NULL,
+  /* sess_check_folder */ pop3driver_cached_check_folder,
+  /* sess_examine_folder */ NULL,
+  /* sess_select_folder */ NULL,
+  /* sess_expunge_folder */ pop3driver_cached_expunge_folder,
+  /* sess_status_folder */ pop3driver_cached_status_folder,
+  /* sess_messages_number */ pop3driver_cached_messages_number,
+  /* sess_recent_number */ pop3driver_cached_recent_number,
+  /* sess_unseen_number */ pop3driver_cached_unseen_number,
+  /* sess_list_folders */ NULL,
+  /* sess_lsub_folders */ NULL,
+  /* sess_subscribe_folder */ NULL,
+  /* sess_unsubscribe_folder */ NULL,
+
+  /* sess_append_message */ NULL,
+  /* sess_append_message_flags */ NULL,
+  /* sess_copy_message */ NULL,
+  /* sess_move_message */ NULL,
+
+  /* sess_get_message */ pop3driver_cached_get_message,
+  /* sess_get_message_by_uid */ pop3driver_cached_get_message_by_uid,
+
+  /* sess_get_messages_list */ pop3driver_cached_get_messages_list,
+  /* sess_get_envelopes_list */ pop3driver_cached_get_envelopes_list,
+  /* sess_remove_message */ pop3driver_cached_remove_message,
+#if 0
+  /* sess_search_messages */ maildriver_generic_search_messages,
+#endif
+
+#else
   .sess_name = "pop3-cached",
 
   .sess_initialize = pop3driver_cached_initialize,
@@ -159,6 +209,7 @@ static mailsession_driver local_pop3_cached_session_driver = {
 
   .sess_get_message = pop3driver_cached_get_message,
   .sess_get_message_by_uid = pop3driver_cached_get_message_by_uid,
+#endif
 };
 
 mailsession_driver * pop3_cached_session_driver =
