@@ -30,15 +30,17 @@
  */
 
 /*
- * $Id: maildriver_types.h,v 1.41 2004/11/21 21:53:34 hoa Exp $
+ * $Id: maildriver_types.h,v 1.42 2005/06/01 12:22:00 smarinier Exp $
  */
 
 #ifndef MAILDRIVER_TYPES_H
 
 #define MAILDRIVER_TYPES_H
 
-#include <inttypes.h>
-#include <sys/types.h>
+#ifndef _MSC_VER
+#	include <inttypes.h>
+#	include <sys/types.h>
+#endif
 
 #include <libetpan/mailstream.h>
 #include <libetpan/mailimf.h>
@@ -71,7 +73,10 @@ struct mailmessage_list {
   carray * msg_tab; /* elements are (mailmessage *) */
 };
 
+LIBETPAN_EXPORT
 struct mailmessage_list * mailmessage_list_new(carray * msg_tab);
+
+LIBETPAN_EXPORT
 void mailmessage_list_free(struct mailmessage_list * env_list);
 
 /*
@@ -84,7 +89,10 @@ struct mail_list {
   clist * mb_list; /* elements are (char *) */
 };
 
+LIBETPAN_EXPORT
 struct mail_list * mail_list_new(clist * mb_list);
+
+LIBETPAN_EXPORT
 void mail_list_free(struct mail_list * resp);
 
 /*
@@ -115,13 +123,17 @@ struct mail_flags {
   clist * fl_extension; /* elements are (char *) */
 };
 
+LIBETPAN_EXPORT
 struct mail_flags * mail_flags_new(uint32_t fl_flags, clist * fl_ext);
+
+LIBETPAN_EXPORT
 void mail_flags_free(struct mail_flags * flags);
 
 /*
   This function creates a flag for a new message
 */
 
+LIBETPAN_EXPORT
 struct mail_flags * mail_flags_new_empty(void);
 
 
@@ -131,6 +143,7 @@ struct mail_flags * mail_flags_new_empty(void);
   
 */
 
+LIBETPAN_EXPORT
 int32_t mailimf_date_time_comp(struct mailimf_date_time * date1,
     struct mailimf_date_time * date2);
 
@@ -759,11 +772,12 @@ struct mailmessage_tree {
   char * node_base_subject;
 };
 
-
+LIBETPAN_EXPORT
 struct mailmessage_tree *
 mailmessage_tree_new(char * node_msgid, time_t node_date,
     mailmessage * node_msg);
 
+LIBETPAN_EXPORT
 void mailmessage_tree_free(struct mailmessage_tree * tree);
 
 /*
@@ -772,7 +786,7 @@ void mailmessage_tree_free(struct mailmessage_tree * tree);
   if you want to release memory of the given tree and all the sub-trees,
   you can use this function.
 */
-
+LIBETPAN_EXPORT
 void mailmessage_tree_free_recursive(struct mailmessage_tree * tree);
 
 
@@ -785,7 +799,7 @@ struct generic_message_t {
   void * msg_data;
 };
 
-
+LIBETPAN_EXPORT
 const char * maildriver_strerror(int err);
 
 #ifdef __cplusplus
