@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstorage_tools.c,v 1.14 2004/11/21 21:53:35 hoa Exp $
+ * $Id: mailstorage_tools.c,v 1.15 2005/06/01 12:22:01 smarinier Exp $
  */
 
 #include "mailstorage_tools.h"
@@ -38,13 +38,15 @@
 #include "libetpan-config.h"
 
 #include <sys/types.h>
-#include <netdb.h>
-#include <netinet/in.h>
-#include <sys/socket.h>
-#include <unistd.h>
 #include <stdlib.h>
-#include <sys/wait.h>
-#include <sys/ioctl.h>
+#ifndef _MSC_VER
+#	include <netdb.h>
+#	include <netinet/in.h>
+#	include <sys/socket.h>
+#	include <unistd.h>
+#	include <sys/wait.h>
+#	include <sys/ioctl.h>
+#endif
 #include <fcntl.h>
 #include <string.h>
 
@@ -60,9 +62,13 @@ static int tcp_connect(char * server, uint16_t port)
 {
   struct hostent * remotehost;
   struct sockaddr_in sa;
-  int s;
   int r;
 
+#ifdef WIN32
+  SOCKET s;
+#else
+  int s;
+#endif
   s = socket(PF_INET, SOCK_STREAM, 0);
   if (s == -1)
     goto err;
@@ -82,13 +88,19 @@ static int tcp_connect(char * server, uint16_t port)
   return s;
 
  close_socket:
+#ifdef WIN32
+  closesocket( s);
+#else
   close(s);
+#endif
  err:
   return -1;
 }
 
 
 /* connection through a shell command */
+/* SEB unsupported on Windows */
+#ifndef WIN32
 
 static void do_exec_command(int fd, const char *command,
     char *servername, uint16_t port)
@@ -144,9 +156,15 @@ static void do_exec_command(int fd, const char *command,
   /* Eep. Shouldn't reach this */
   exit(1);
 }
+#endif /* WIN32 */
 
 static int subcommand_connect(char *command, char *servername, uint16_t port)
 {
+/* SEB unsupported on Windows */
+#ifdef WIN32
+	return -1;
+#else
+
   int sockfds[2];
   pid_t childpid;
   
@@ -169,6 +187,7 @@ static int subcommand_connect(char *command, char *servername, uint16_t port)
   waitpid(childpid, NULL, 0);
   
   return sockfds[0];
+#endif /* WIN32 */
 }
 
 int mailstorage_generic_connect(mailsession_driver * driver,
@@ -207,7 +226,6 @@ int mailstorage_generic_connect(mailsession_driver * driver,
   case CONNECTION_TYPE_COMMAND_TLS:
     fd = subcommand_connect(command, servername, port);
     break;
-    
   default:
     fd = -1;
     break;
