@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imfcache.c,v 1.16 2004/11/21 21:53:35 hoa Exp $
+ * $Id: imfcache.c,v 1.17 2005/06/01 16:04:43 hoa Exp $
  */
 
 #include "imfcache.h"
@@ -176,7 +176,7 @@ int mailimf_cache_int_write(MMAPString * mmapstr, size_t * index,
   for(i = 0 ; i < 4 ; i ++) {
     ch = value % 256;
 
-    r = mail_serialize_write(mmapstr, index, &ch, 1);
+    r = mail_serialize_write(mmapstr, index, (char *) &ch, 1);
     if (r != MAIL_NO_ERROR)
       return r;
     value /= 256;
@@ -195,7 +195,7 @@ int mailimf_cache_int_read(MMAPString * mmapstr, size_t * index,
   
   value = 0;
   for(i = 0 ; i < 4 ; i ++) {
-    r = mail_serialize_read(mmapstr, index, &ch, 1);
+    r = mail_serialize_read(mmapstr, index, (char *) &ch, 1);
     if (r != MAIL_NO_ERROR)
       return r;
     value = value | ch << (i << 3);
@@ -318,6 +318,7 @@ int mailimf_cache_fields_read(MMAPString * mmapstr, size_t * index,
   for(i = 0 ; i < count ; i++) {
     struct mailimf_field * field;
 
+    field = NULL;
     r = mailimf_cache_field_read(mmapstr, index, &field);
     if (r != MAIL_NO_ERROR) {
       res = r;
