@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailthread.c,v 1.25 2004/11/21 21:53:35 hoa Exp $
+ * $Id: mailthread.c,v 1.27 2005/06/01 12:22:01 smarinier Exp $
  */
 
 #include "mailthread.h"
@@ -46,6 +46,14 @@
 #include "carray.h"
 #include "clist.h"
 #include "mailmessage.h"
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#endif
+
+/* SEB */
+#ifdef NO_MACROS
+#	define inline
+#endif
 
 static inline char * get_msg_id(mailmessage * msg)
 {
@@ -490,7 +498,7 @@ static time_t mkgmtime(struct tm * tmp)
   register int			bits;
   register int			saved_seconds;
   time_t				t;
-  struct tm			yourtm, *mytm;
+  struct tm			yourtm, mytm;
   
   yourtm = *tmp;
   saved_seconds = yourtm.tm_sec;
@@ -508,8 +516,8 @@ static time_t mkgmtime(struct tm * tmp)
   */
   t = (t < 0) ? 0 : ((time_t) 1 << bits);
   for ( ; ; ) {
-    mytm = gmtime(&t);
-    dir = tmcomp(mytm, &yourtm);
+    gmtime_r(&t, &mytm);
+    dir = tmcomp(&mytm, &yourtm);
     if (dir != 0) {
       if (bits-- < 0)
 	return WRONG;
