@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailengine.c,v 1.7 2005/01/31 01:07:50 hoa Exp $
+ * $Id: mailengine.c,v 1.8 2005/06/13 07:24:07 hoa Exp $
  */
 
 #include "mailengine.h"
@@ -186,16 +186,22 @@ struct message_ref_elt {
   int mime_ref_count;
   struct mailfolder * folder;
   int lost;
+  pthread_mutex_t lock;
 };
 
 static struct message_ref_elt *
 message_ref_elt_new(struct mailfolder * folder, mailmessage * msg)
 {
   struct message_ref_elt * ref;
-
+  int r;
+  
   ref = malloc(sizeof(* ref));
   if (ref == NULL)
-    return NULL;
+    goto err;
+  
+  r = pthread_mutex_init(&ref->lock, NULL);
+  if (r != 0)
+    goto free;
   
   ref->msg = msg;
   ref->ref_count = 0;
@@ -204,25 +210,45 @@ message_ref_elt_new(struct mailfolder * folder, mailmessage * msg)
   ref->lost = 0;
   
   return ref;
+  
+ free:
+  free(ref);
+ err:
+  return NULL;
 }
 
 static void message_ref_elt_free(struct message_ref_elt * ref_elt)
 {
+  pthread_mutex_destroy(&ref_elt->lock);
   free(ref_elt);
 }
 
 static inline int message_ref(struct message_ref_elt * ref_elt)
 {
-  ref_elt->ref_count ++;
+  int count;
   
-  return ref_elt->ref_count;
+  pthread_mutex_lock(&ref_elt->lock);
+  
+  ref_elt->ref_count ++;
+  count = ref_elt->ref_count;
+  
+  pthread_mutex_unlock(&ref_elt->lock);
+  
+  return count;
 }
 
 static inline int message_unref(struct message_ref_elt * ref_elt)
 {
+  int count;
+  
+  pthread_mutex_lock(&ref_elt->lock);
+  
   ref_elt->ref_count --;
-
-  return ref_elt->ref_count;
+  count = ref_elt->ref_count;
+  
+  pthread_mutex_unlock(&ref_elt->lock);
+  
+  return count;
 }
 
 
@@ -230,6 +256,7 @@ static inline int message_mime_ref(struct mailprivacy * privacy,
     struct message_ref_elt * ref_elt)
 {
   int r;
+  int count;
   
   if (ref_elt->mime_ref_count == 0) {
     struct mailmime * mime;
@@ -241,22 +268,32 @@ static inline int message_mime_ref(struct mailprivacy * privacy,
   
   message_ref(ref_elt);
   
+  pthread_mutex_lock(&ref_elt->lock);
   ref_elt->mime_ref_count ++;
+  count = ref_elt->mime_ref_count;
+  pthread_mutex_unlock(&ref_elt->lock);
   
-  return ref_elt->mime_ref_count;
+  return count;
 }
 
 static inline int message_mime_unref(struct mailprivacy * privacy,
     struct message_ref_elt * ref_elt)
 {
+  int count;
+  
   message_unref(ref_elt);
   
+  pthread_mutex_lock(&ref_elt->lock);
   ref_elt->mime_ref_count --;
   
   if (ref_elt->mime_ref_count == 0)
     mailprivacy_msg_flush(privacy, ref_elt->msg);
   
-  return ref_elt->mime_ref_count;
+  count = ref_elt->mime_ref_count;
+  
+  pthread_mutex_unlock(&ref_elt->lock);
+  
+  return count;
 }
 
 
