@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy.c,v 1.3 2005/02/17 01:44:50 hoa Exp $
+ * $Id: mailprivacy.c,v 1.4 2005/06/01 16:04:44 hoa Exp $
  */
 
 #include "mailprivacy.h"
@@ -79,13 +79,6 @@ static int check_tmp_dir(char * tmp_dir)
 struct mailprivacy * mailprivacy_new(char * tmp_dir, int make_alternative)
 {
   struct mailprivacy * privacy;
-  int r;
-
-#if 0 
-  r = check_tmp_dir(tmp_dir);
-  if (r != MAIL_NO_ERROR)
-    goto err;
-#endif
   
   privacy = malloc(sizeof(* privacy));
   if (privacy == NULL)
