@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy_smime.c,v 1.4 2004/12/27 14:08:25 hoa Exp $
+ * $Id: mailprivacy_smime.c,v 1.6 2005/06/01 16:04:44 hoa Exp $
  */
 
 #include "mailprivacy_smime.h"
@@ -593,6 +593,19 @@ smime_verify(struct mailprivacy * privacy,
     goto unlink_description;
   }
   
+  /* insert the signed part */
+  if (!sign_ok) {
+    clistiter * child_iter;
+    struct mailmime * child;
+    
+    child_iter = clist_begin(mime->mm_data.mm_multipart.mm_mp_list);
+    child = clist_content(child_iter);
+    
+    r = mailprivacy_fetch_mime_body_to_file(privacy,
+        stripped_filename, sizeof(stripped_filename),
+        msg, child);
+  }
+  
   r = mailprivacy_get_part_from_file(privacy, 1,
       stripped_filename, &stripped_mime);
   if (r != MAIL_NO_ERROR) {
@@ -1558,7 +1571,6 @@ void mailprivacy_smime_set_CA_dir(struct mailprivacy * privacy,
   
   while ((ent = readdir(dir)) != NULL) {
     char filename[PATH_MAX];
-    char command[PATH_MAX];
     char buf[MAX_BUF];
     FILE * f;
     
