@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy_tools.c,v 1.3 2004/11/21 21:53:35 hoa Exp $
+ * $Id: mailprivacy_tools.c,v 1.4 2005/01/28 01:43:12 hoa Exp $
  */
 
 #include "mailprivacy_tools.h"
@@ -451,6 +451,28 @@ int mailprivacy_get_mime(struct mailprivacy * privacy,
   return res;
 }
 
+#ifndef LIBETPAN_SYSTEM_BASENAME
+static char * libetpan_basename(char * filename)
+{
+  char * next;
+  char * p;
+  
+  p = filename;
+  next = strchr(p, '/');
+  
+  while (next != NULL) {
+    p = next;
+    next = strchr(p + 1, '/');
+  }
+  
+  if (p == filename)
+    return filename;
+  else
+    return p + 1;
+}
+#else
+#define libetpan_basename(a) basename(a)
+#endif
 
 struct mailmime *
 mailprivacy_new_file_part(struct mailprivacy * privacy,
@@ -471,7 +493,7 @@ mailprivacy_new_file_part(struct mailprivacy * privacy,
   
   if (filename != NULL) {
     strncpy(basename_buf, filename, PATH_MAX);
-    name = basename(basename_buf);
+    name = libetpan_basename(basename_buf);
   }
   else {
     name = NULL;
