@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_sender.c,v 1.21 2004/11/21 21:53:36 hoa Exp $
+ * $Id: mailimap_sender.c,v 1.25 2005/07/18 14:02:33 hoa Exp $
  */
 
 #include "mailstream.h"
@@ -222,7 +222,7 @@ static inline int mailimap_sized_token_send(mailstream * fd, const char * atom,
   return MAILIMAP_NO_ERROR;
 }
 
-static int mailimap_token_send(mailstream * fd, const char * atom)
+int mailimap_token_send(mailstream * fd, const char * atom)
 {
   return mailimap_sized_token_send(fd, atom, strlen(atom));
 }
@@ -400,8 +400,10 @@ static int is_atom(const char * str)
   while (* str != '\0') {
     unsigned char uch = (unsigned char) * str;
     
-    if (!isalnum(uch))
-      return 0;
+    if (uch != '-') {
+      if (!isalnum(uch))
+        return 0;
+    }
     
     str ++;
   }
@@ -863,8 +865,11 @@ static int mailimap_fixed_digit_send(mailstream * fd,
 				     int num, int count)
 {
   int r;
-
-  r = mailimap_fixed_digit_send(fd, num / 10, count);
+  
+  if (count == 0)
+    return MAILIMAP_NO_ERROR;
+  
+  r = mailimap_fixed_digit_send(fd, num / 10, count - 1);
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
@@ -875,7 +880,7 @@ static int mailimap_fixed_digit_send(mailstream * fd,
   return MAILIMAP_NO_ERROR;
 }
 
-static int mailimap_date_year_send(mailstream *fd, int year)
+static int mailimap_date_year_send(mailstream * fd, int year)
 {
   int r;
 
@@ -2605,24 +2610,26 @@ mailimap_store_att_flags_send(mailstream * fd,
   switch (store_flags->fl_sign) {
   case 1:
     r = mailimap_char_send(fd, '+');
-	if (r != MAILIMAP_NO_ERROR)
-	  return r;
+    if (r != MAILIMAP_NO_ERROR)
+      return r;
+    break;
   case -1:
     r = mailimap_char_send(fd, '-');
-	if (r != MAILIMAP_NO_ERROR)
+    if (r != MAILIMAP_NO_ERROR)
       return r;
+    break;
   }
-
+  
   r = mailimap_token_send(fd, "FLAGS");
   if (r != MAILIMAP_NO_ERROR)
     return r;
 
   if (store_flags->fl_silent) {
     r = mailimap_token_send(fd, ".SILENT");
-	if (r != MAILIMAP_NO_ERROR)
-	  return r;
+    if (r != MAILIMAP_NO_ERROR)
+      return r;
   }
-
+  
   r = mailimap_space_send(fd);
   if (r != MAILIMAP_NO_ERROR)
     return r;
