@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_types.h,v 1.21 2004/11/21 21:53:36 hoa Exp $
+ * $Id: mailimap_types.h,v 1.25 2005/07/16 17:55:57 hoa Exp $
  */
 
 /*
@@ -506,7 +506,7 @@
 extern "C" {
 #endif
 
-#include <inttypes.h>
+#include <libetpan/libetpan-config.h>
 #include <libetpan/mailstream.h>
 #include <libetpan/clist.h>
 
@@ -3103,6 +3103,16 @@ struct mailimap {
   struct mailimap_connection_info * imap_connection_info;
   struct mailimap_selection_info * imap_selection_info;
   struct mailimap_response_info * imap_response_info;
+  
+  struct {
+    void * sasl_conn;
+    const char * sasl_server_fqdn;
+    const char * sasl_login;
+    const char * sasl_auth_name;
+    const char * sasl_password;
+    const char * sasl_realm;
+    void * sasl_secret;
+  } imap_sasl;
 };
 
 typedef struct mailimap mailimap;
