@@ -31,10 +31,20 @@
 
 #include "mailimf_types_helper.h"
 
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <unistd.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#endif
 
 #include "mailimf.h"
 
@@ -1308,7 +1318,7 @@ struct mailimf_date_time * mailimf_get_current_date(void)
 
 
 /* mkgmtime.c - make time corresponding to a GMT timeval struct
- $Id: mailimf_types_helper.c,v 1.14 2004/11/21 21:53:37 hoa Exp $
+ $Id: mailimf_types_helper.c,v 1.16 2005/06/01 20:23:16 hoa Exp $
  
  * Copyright (c) 1998-2000 Carnegie Mellon University.  All rights reserved.
  *
