@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildir.c,v 1.12 2005/01/28 01:43:12 hoa Exp $
+ * $Id: maildir.c,v 1.13 2005/06/01 12:22:18 smarinier Exp $
  */
 
 #include "maildir.h"
@@ -38,12 +38,16 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include <unistd.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#else
+#	include <unistd.h>
+#	include <sys/mman.h>
+#	include <dirent.h>
+#endif
 #include <sys/types.h>
-#include <dirent.h>
 #include <time.h>
 #include <sys/stat.h>
-#include <sys/mman.h>
 #include <errno.h>
 #include <fcntl.h>
 
