@@ -30,19 +30,22 @@
  */
 
 /*
- * $Id: mailmbox.c,v 1.39 2004/11/21 21:53:38 hoa Exp $
+ * $Id: mailmbox.c,v 1.41 2005/06/01 16:04:46 hoa Exp $
  */
 
 #include "mailmbox.h"
 
-#include <sys/file.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#else
+#	include <sys/file.h>
+#	include <unistd.h>
+#	include <sys/mman.h>
+#endif
 #include <sys/stat.h>
-#include <unistd.h>
-#include <sys/mman.h>
 #include <fcntl.h>
 #include <time.h>
 #include <sys/types.h>
-#include <unistd.h>
 
 #include <string.h>
 #include <ctype.h>
@@ -569,6 +572,8 @@ static char * write_fixed_message(char * str,
     size_t count;
     const char * next;
 
+    count = 0;
+    next = NULL;
     str = write_fixed_line(str, cur_src, left, &next, &count);
     
     cur_src = next;
