@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_content.c,v 1.39 2004/12/13 22:22:36 hoa Exp $
+ * $Id: mailmime_content.c,v 1.40 2005/06/01 12:22:19 smarinier Exp $
  */
 
 #include "mailimf.h"
@@ -67,6 +67,7 @@ static int mailmime_parse_with_default(const char * message, size_t length,
 
 
 
+LIBETPAN_EXPORT
 char * mailmime_content_charset_get(struct mailmime_content * content)
 {
   char * charset;
@@ -78,6 +79,7 @@ char * mailmime_content_charset_get(struct mailmime_content * content)
     return charset;
 }
 
+LIBETPAN_EXPORT
 char * mailmime_content_param_get(struct mailmime_content * content,
 				  char * name)
 {
@@ -572,7 +574,6 @@ mailmime_body_part_dash2_transport_crlf_parse(const char * message,
 {
   size_t cur_token;
   int r;
-  size_t after_boundary;
   const char * data_str;
   size_t data_size;
   const char * begin_text;
@@ -637,7 +638,6 @@ mailmime_body_part_dash2_close_parse(const char * message,
 {
   size_t cur_token;
   int r;
-  size_t after_boundary;
   const char * data_str;
   size_t data_size;
   const char * begin_text;
@@ -780,6 +780,7 @@ enum {
   MULTIPART_NEXT_STATE_2
 };
 
+LIBETPAN_EXPORT
 int mailmime_multipart_next_parse(const char * message, size_t length,
 				  size_t * index)
 {
@@ -1043,10 +1044,11 @@ mailmime_multipart_body_parse(const char * message, size_t length,
     size_t data_size;
     struct mailimf_fields * fields;
     struct mailmime_fields * mime_fields;
-    int got_crlf;
-    size_t after_boundary;
 
 #if 0    
+    int got_crlf;
+    size_t after_boundary;
+    
     /* XXX - begin */
     r = mailmime_body_part_dash2_parse(message, length, &cur_token,
 				       boundary, &data_str, &data_size);
@@ -1282,6 +1284,7 @@ enum {
 };
 
 
+LIBETPAN_EXPORT
 int mailmime_parse(const char * message, size_t length,
 		   size_t * index, struct mailmime ** result)
 {
@@ -1349,6 +1352,7 @@ int mailmime_parse(const char * message, size_t length,
 }
 
 
+LIBETPAN_EXPORT
 char * mailmime_extract_boundary(struct mailmime_content * content_type)
 {
   char * boundary;
@@ -1741,6 +1745,7 @@ static int mailmime_get_section_list(struct mailmime * mime,
   }
 }
 
+LIBETPAN_EXPORT
 int mailmime_get_section(struct mailmime * mime,
 			 struct mailmime_section * section,
 			 struct mailmime ** result)
