@@ -30,19 +30,29 @@
  */
 
 /*
- * $Id: mailmime_types_helper.c,v 1.22 2004/11/21 21:53:39 hoa Exp $
+ * $Id: mailmime_types_helper.c,v 1.24 2005/06/01 20:23:16 hoa Exp $
  */
 
 #include "mailmime_types_helper.h"
-#include "clist.h"
 
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
+#include "clist.h"
 #include "mailmime.h"
 
 #include <string.h>
 #include <time.h>
 #include <sys/types.h>
-#include <unistd.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
 #include <stdlib.h>
+#ifdef _MSC_VER
+#	include "win_etpan.h"
+#endif
 
 #define MIME_VERSION (1 << 16)
 
