@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: newsnntp_ssl.c,v 1.11 2004/11/21 21:53:39 hoa Exp $
+ * $Id: newsnntp_ssl.c,v 1.12 2005/06/01 12:22:20 smarinier Exp $
  */
 
 #include "newsnntp_ssl.h"
@@ -38,8 +38,12 @@
 #include "newsnntp.h"
 
 #include "connect.h"
-#include <netinet/in.h>
-#include <unistd.h>
+#if HAVE_NETINET_IN_H
+#	include <netinet/in.h>
+#endif
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
 
 #define DEFAULT_NNTPS_PORT 563
 #define SERVICE_NAME_NNTPS "nntps"
