@@ -32,21 +32,36 @@
  */
 
 /*
- * $Id: mailsmtp.c,v 1.17 2004/11/21 21:53:40 hoa Exp $
+ * $Id: mailsmtp.c,v 1.20 2005/07/16 17:55:57 hoa Exp $
  */
 
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
 #include "mailsmtp.h"
 #include "connect.h"
 #include "md5.h"
 #include "base64.h"
 #include "mail.h"
 
-#include <netinet/in.h>
+#if HAVE_NETINET_IN_H
+#	include <netinet/in.h>
+#endif
 #include <string.h>
 #include <stdlib.h>
-#include <unistd.h>
+#if HAVE_UNISTD_H
+#	include <unistd.h>
+#endif
 #include <stdio.h>
 
+#ifdef USE_SASL
+#include <sasl/sasl.h>
+#include <sasl/saslutil.h>
+#endif
+
+#include "mailsasl.h"
 
 /*
   RFC 2821 : SMTP
@@ -98,7 +113,11 @@ mailsmtp * mailsmtp_new(size_t progr_rate,
 
   session->esmtp = 0;
   session->auth = MAILSMTP_AUTH_NOT_CHECKED;
-
+  
+#ifdef USE_SASL
+  session->smtp_sasl.sasl_conn = NULL;
+#endif
+  
   return session;
 
  free_line_buffer:
@@ -111,6 +130,13 @@ mailsmtp * mailsmtp_new(size_t progr_rate,
 
 void mailsmtp_free(mailsmtp * session)
 {
+#ifdef USE_SASL
+  if (session->smtp_sasl.sasl_conn != NULL) {
+    sasl_dispose((sasl_conn_t **) &session->smtp_sasl.sasl_conn);
+    mailsasl_unref();
+  }
+#endif
+  
   if (session->stream)
     mailsmtp_quit(session);
 
@@ -381,6 +407,9 @@ int mailesmtp_parse_ehlo(mailsmtp * session)
 	} else if (strncasecmp(response, "PLAIN", 5) == 0) {
 	  session->auth |= MAILSMTP_AUTH_PLAIN;
 	  response += 5;
+	} else if (strncasecmp(response, "DIGEST-MD5", 10) == 0) {
+	  session->auth |= MAILSMTP_AUTH_DIGEST_MD5;
+	  response += 10;
 	} else {
 	  /* unknown auth method - jump to next word or eol */
 	  while (!isdelim(response[0]) || response[0] == '\r')
@@ -647,6 +676,7 @@ static int mailsmtp_auth_login(mailsmtp * session,
   return err;
 }
 
+#if 0
 static int mailsmtp_auth_plain(mailsmtp * session,
     const char * user, const char * pass)
 {
@@ -721,7 +751,7 @@ static char * hash_md5(const char * sec_key, const char * data, int len)
   }
 
   hmac_md5(data, len, key, 64, digest);
-  hash_hex = convert_hex(digest, 16);
+  hash_hex = convert_hex((unsigned char *) digest, 16);
 
   return hash_hex;
 }
@@ -768,10 +798,12 @@ err_free_response:
   free(response);
   return err;
 }
+#endif
 
 int mailsmtp_auth_type(mailsmtp * session,
     const char * user, const char * pass, int type)
 {
+#if 0 /* deprecated */
   int err;
   char command[SMTP_STRING_SIZE];
   
@@ -811,6 +843,44 @@ int mailsmtp_auth_type(mailsmtp * session,
   default:
     return MAILSMTP_ERROR_NOT_IMPLEMENTED;
   }
+#endif
+  int err;
+  char command[SMTP_STRING_SIZE];
+  
+  if (session->auth == MAILSMTP_AUTH_NOT_CHECKED) 
+    return MAILSMTP_ERROR_BAD_SEQUENCE_OF_COMMAND;
+    
+  if ( !(session->auth & type) ) return MAILSMTP_ERROR_AUTH_NOT_SUPPORTED;
+  
+  switch (type) {
+  case MAILSMTP_AUTH_LOGIN:
+    {
+      snprintf(command, SMTP_STRING_SIZE, "AUTH LOGIN\r\n");
+      err = send_command(session, command);
+      if (err == -1) return MAILSMTP_ERROR_STREAM;
+      
+      err = read_response(session);
+      err = auth_map_errors(err);
+      if (err != MAILSMTP_NO_ERROR) return err;
+      
+      return mailsmtp_auth_login(session, user, pass);
+    }
+  case MAILSMTP_AUTH_PLAIN:
+    return mailesmtp_auth_sasl(session, "PLAIN",
+        NULL, NULL, NULL, user, user, pass, NULL);
+    
+  case MAILSMTP_AUTH_CRAM_MD5:
+    return mailesmtp_auth_sasl(session, "CRAM-MD5",
+        NULL, NULL, NULL, user, user, pass, NULL);
+    
+  case MAILSMTP_AUTH_DIGEST_MD5:
+    return mailesmtp_auth_sasl(session, "DIGEST-MD5",
+        NULL, NULL, NULL, user, user, pass, NULL);
+    
+  default:
+    return MAILSMTP_ERROR_NOT_IMPLEMENTED;
+  }
+
 }
 
 
@@ -819,7 +889,9 @@ int mailsmtp_auth(mailsmtp * session, const char * user, const char * pass)
   if (session->auth == MAILSMTP_AUTH_NOT_CHECKED) 
     return MAILSMTP_ERROR_BAD_SEQUENCE_OF_COMMAND;
     
-  if (session->auth & MAILSMTP_AUTH_CRAM_MD5) {
+  if (session->auth & MAILSMTP_AUTH_DIGEST_MD5) {
+    return mailsmtp_auth_type(session, user, pass, MAILSMTP_AUTH_DIGEST_MD5);
+  } else if (session->auth & MAILSMTP_AUTH_CRAM_MD5) {
     return mailsmtp_auth_type(session, user, pass, MAILSMTP_AUTH_CRAM_MD5);
   } else if (session->auth & MAILSMTP_AUTH_PLAIN) {
     return mailsmtp_auth_type(session, user, pass, MAILSMTP_AUTH_PLAIN);
@@ -982,3 +1054,255 @@ const char * mailsmtp_strerror(int errnum)
     return "Unknown error code";
   }
 }
+
+
+#ifdef USE_SASL
+static int sasl_getsimple(void * context, int id,
+    const char ** result, unsigned * len)
+{
+  mailsmtp * session;
+  
+  session = context;
+  
+  switch (id) {
+  case SASL_CB_USER:
+    if (result != NULL)
+      * result = session->smtp_sasl.sasl_login;
+    if (len != NULL)
+      * len = strlen(session->smtp_sasl.sasl_login);
+    return SASL_OK;
+    
+  case SASL_CB_AUTHNAME:
+    if (result != NULL)
+      * result = session->smtp_sasl.sasl_auth_name;
+    if (len != NULL)
+      * len = strlen(session->smtp_sasl.sasl_auth_name);
+    return SASL_OK;
+  }
+  
+  return SASL_FAIL;
+}
+
+static int sasl_getsecret(sasl_conn_t * conn, void * context, int id,
+    sasl_secret_t ** psecret)
+{
+  mailsmtp * session;
+  
+  session = context;
+  
+  switch (id) {
+  case SASL_CB_PASS:
+    if (psecret != NULL)
+      * psecret = session->smtp_sasl.sasl_secret;
+    return SASL_OK;
+  }
+  
+  return SASL_FAIL;
+}
+
+static int sasl_getrealm(void * context, int id,
+    const char ** availrealms,
+    const char ** result)
+{
+  mailsmtp * session;
+  
+  session = context;
+  
+  switch (id) {
+  case SASL_CB_GETREALM:
+    if (result != NULL)
+      * result = session->smtp_sasl.sasl_realm;
+    return SASL_OK;
+  }
+  
+  return SASL_FAIL;
+}
+#endif
+
+int mailesmtp_auth_sasl(mailsmtp * session, const char * auth_type,
+    const char * server_fqdn,
+    const char * local_ip_port,
+    const char * remote_ip_port,
+    const char * login, const char * auth_name,
+    const char * password, const char * realm)
+{
+#ifdef USE_SASL
+  int r;
+  char command[SMTP_STRING_SIZE];
+  sasl_callback_t sasl_callback[5];
+  const char * sasl_out;
+  unsigned sasl_out_len;
+  const char * mechusing;
+  sasl_secret_t * secret;
+  int res;
+  size_t len;
+  char * encoded;
+  unsigned int encoded_len;
+  unsigned int max_encoded;
+  
+  sasl_callback[0].id = SASL_CB_GETREALM;
+  sasl_callback[0].proc =  sasl_getrealm;
+  sasl_callback[0].context = session;
+  sasl_callback[1].id = SASL_CB_USER;
+  sasl_callback[1].proc =  sasl_getsimple;
+  sasl_callback[1].context = session;
+  sasl_callback[2].id = SASL_CB_AUTHNAME;
+  sasl_callback[2].proc =  sasl_getsimple;
+  sasl_callback[2].context = session; 
+  sasl_callback[3].id = SASL_CB_PASS;
+  sasl_callback[3].proc =  sasl_getsecret;
+  sasl_callback[3].context = session;
+  sasl_callback[4].id = SASL_CB_LIST_END;
+  sasl_callback[4].proc =  NULL;
+  sasl_callback[4].context = NULL;
+  
+  len = strlen(password);
+  secret = malloc(sizeof(* secret) + len);
+  if (secret == NULL) {
+    res = MAILSMTP_ERROR_MEMORY;
+    goto err;
+  }
+  secret->len = len;
+  memcpy(secret->data, password, len + 1);
+  
+  session->smtp_sasl.sasl_server_fqdn = server_fqdn;
+  session->smtp_sasl.sasl_login = login;
+  session->smtp_sasl.sasl_auth_name = auth_name;
+  session->smtp_sasl.sasl_password = password;
+  session->smtp_sasl.sasl_realm = realm;
+  session->smtp_sasl.sasl_secret = secret;
+  
+  /* init SASL */
+  mailsasl_ref();
+  
+  r = sasl_client_new("smtp", server_fqdn,
+      local_ip_port, remote_ip_port, sasl_callback, 0,
+      (sasl_conn_t **) &session->smtp_sasl.sasl_conn);
+  if (r != SASL_OK) {
+    res = MAILSMTP_ERROR_AUTH_LOGIN;
+    goto free_secret;
+  }
+  
+  r = sasl_client_start(session->smtp_sasl.sasl_conn,
+      auth_type, NULL, &sasl_out, &sasl_out_len, &mechusing);
+  if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
+    res = MAILSMTP_ERROR_AUTH_LOGIN;
+    goto free_secret;
+  }
+  
+  if (sasl_out_len != 0) {
+    max_encoded = ((sasl_out_len + 2) / 3) * 4;
+    encoded = malloc(max_encoded + 1);
+    if (encoded == NULL) {
+      res = MAILSMTP_ERROR_MEMORY;
+      goto free_secret;
+    }
+    
+    r = sasl_encode64(sasl_out, sasl_out_len,
+        encoded, max_encoded + 1, &encoded_len);
+    if (r != SASL_OK) {
+      free(encoded);
+      res = MAILSMTP_ERROR_MEMORY;
+      goto free_secret;
+    }
+    
+    snprintf(command, SMTP_STRING_SIZE, "AUTH %s %s\r\n", auth_type, encoded);
+    
+    free(encoded);
+  }
+  else {
+    snprintf(command, SMTP_STRING_SIZE, "AUTH %s\r\n", auth_type);
+  }
+  
+  r = send_command(session, command);
+  if (r == -1) {
+    res = MAILSMTP_ERROR_STREAM;
+    goto free_secret;
+  }
+  
+  while (1) {
+    r = read_response(session);
+    switch (r) {
+    case 220:
+    case 235:
+      free(session->smtp_sasl.sasl_secret);
+      return MAILSMTP_NO_ERROR;
+    
+    case 334:
+      {
+        size_t response_len;
+        char * decoded;
+        unsigned int decoded_len;
+        unsigned int max_decoded;
+        
+        response_len = strlen(session->response);
+        max_decoded = response_len * 3 / 4;
+        decoded = malloc(max_decoded + 1);
+        if (decoded == NULL) {
+          res = MAILSMTP_ERROR_MEMORY;
+          goto free_secret;
+        }
+        
+        r = sasl_decode64(session->response, response_len,
+            decoded, max_decoded + 1, &decoded_len);
+        
+        if (r != SASL_OK) {
+          free(decoded);
+          res = MAILSMTP_ERROR_MEMORY;
+          goto free_secret;
+        }
+        
+        r = sasl_client_step(session->smtp_sasl.sasl_conn,
+            decoded, decoded_len, NULL, &sasl_out, &sasl_out_len);
+        
+        free(decoded);
+        
+        if ((r != SASL_CONTINUE) && (r != SASL_OK)) {
+          res = MAILSMTP_ERROR_AUTH_LOGIN;
+          goto free_secret;
+        }
+        
+        max_encoded = ((sasl_out_len + 2) / 3) * 4;
+        encoded = malloc(max_encoded + 1);
+        if (encoded == NULL) {
+          res = MAILSMTP_ERROR_MEMORY;
+          goto free_secret;
+        }
+        
+        r = sasl_encode64(sasl_out, sasl_out_len,
+            encoded, max_encoded + 1, &encoded_len);
+        if (r != SASL_OK) {
+          free(encoded);
+          res = MAILSMTP_ERROR_MEMORY;
+          goto free_secret;
+        }
+        
+        snprintf(command, SMTP_STRING_SIZE, "%s\r\n", encoded);
+        r = send_command(session, command);
+        
+        free(encoded);
+        
+        if (r == -1) {
+          res = MAILSMTP_ERROR_STREAM;
+          goto free_secret;
+        }
+      }
+      break;
+      
+    default:
+      res = auth_map_errors(r);
+      goto free_secret;
+    }
+  }
+  
+  return MAILSMTP_NO_ERROR;
+  
+ free_secret:
+  free(session->smtp_sasl.sasl_secret);
+ err:
+  return res;
+#else
+  return MAILSMTP_ERROR_NOT_IMPLEMENTED;
+#endif
+}
+
